@@ -25,6 +25,8 @@ use cl3::memory::{
 use cl3::types::{cl_device_svm_capabilities, cl_svm_mem_flags, cl_uint};
 use libc::c_void;
 #[cfg(feature = "serde")]
+use serde::de::{Deserialize, DeserializeSeed, Deserializer, Error, SeqAccess, Visitor};
+#[cfg(feature = "serde")]
 use serde::ser::{Serialize, SerializeSeq, Serializer};
 use std::alloc::{self, Layout};
 use std::fmt;
@@ -527,6 +529,60 @@ impl<'a, T: Debug> fmt::Debug for SvmVec<'a, T> {
     }
 }
 
+/// A DeserializeSeed implementation  that uses stateful deserialization to
+/// append array elements onto the end of an existing SvmVec.
+/// The pre-existing state ("seed") in this case is the SvmVec<'b, T>.
+#[cfg(feature = "serde")]
+pub struct ExtendSvmVec<'a, 'b, T: 'a>(pub &'a mut SvmVec<'b, T>);
+
+#[cfg(feature = "serde")]
+impl<'de, 'a, 'b, T> DeserializeSeed<'de> for ExtendSvmVec<'a, 'b, T>
+where
+    T: Deserialize<'de>,
+{
+    // The return type of the `deserialize` method. Since this implementation
+    // appends onto an existing SvmVec the return type is ().
+    type Value = ();
+
+    fn deserialize<D>(self, deserializer: D) -> result::Result<Self::Value, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        // Visitor implementation to walk an array of the deserializer input.
+        struct ExtendSvmVecVisitor<'a, 'b, T: 'a>(&'a mut SvmVec<'b, T>);
+
+        impl<'de, 'a, 'b, T> Visitor<'de> for ExtendSvmVecVisitor<'a, 'b, T>
+        where
+            T: Deserialize<'de>,
+        {
+            type Value = ();
+
+            fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
+                formatter.write_str("an array")
+            }
+
+            fn visit_seq<A>(self, mut seq: A) -> result::Result<(), A::Error>
+            where
+                A: SeqAccess<'de>,
+            {
+                // reserve SvmVec memory if the size of the deserializer array is known
+                if let Some(size) = seq.size_hint() {
+                    let len = self.0.len + size;
+                    self.0.reserve(len).map_err(A::Error::custom)?;
+                }
+                
+                // Visit each element in the array and push it onto the existing SvmVec
+                while let Some(elem) = seq.next_element()? {
+                    self.0.push(elem);
+                }
+                Ok(())
+            }
+        }
+
+        deserializer.deserialize_seq(ExtendSvmVecVisitor(self.0))
+    }
+}
+
 #[cfg(feature = "serde")]
 impl<'a, T> Serialize for SvmVec<'a, T>
 where
